@@ -1,4 +1,4 @@
-/* $Id: synctime.c,v 1.17 2010-03-29 05:44:32 rikster5 Exp $ */
+/* $Id: synctime.c,v 1.20 2011-02-09 20:41:46 rousseau Exp $ */
 
 /*******************************************************************************
  * synctime.c
@@ -73,8 +73,7 @@ int plugin_help(char **text, int *width, int *height)
         "\n"
         "SyncTime plugin for J-Pilot was written by\n"
         "Judd Montgomery (c) 1999.\n"
-        "judd@jpilot.org\n"
-        "http://jpilot.org\n"
+        "judd@jpilot.org, http://jpilot.org\n"
         "\n"
         "SyncTime WILL NOT work with PalmOS 3.3!"
         ),
@@ -82,12 +81,12 @@ int plugin_help(char **text, int *width, int *height)
       );
    *height = 0;
    *width = 0;
+
    return EXIT_SUCCESS;
 }
 
 int plugin_sync(int sd)
 {
-   int r;
    time_t ltime;
    unsigned long ROMversion, majorVersion, minorVersion;
 
@@ -113,7 +112,7 @@ int plugin_sync(int sd)
    jp_logf(JP_LOG_GUI, _("synctime: Setting the time on the pilot... "));
    
    time(&ltime);
-   r = dlp_SetSysDateTime(sd, ltime);
+   dlp_SetSysDateTime(sd, ltime);
    
    jp_logf(JP_LOG_GUI, _("Done\n"));
 
