@@ -1,4 +1,4 @@
-/* $Id: prefs.h,v 1.50 2009/01/22 22:09:38 rikster5 Exp $ */
+/* $Id: prefs.h,v 1.54 2011-02-10 23:28:07 rikster5 Exp $ */
 
 /*******************************************************************************
  * prefs.h
@@ -29,7 +29,7 @@
 #define PREF_TIME 1
 #define PREF_SHORTDATE 2
 #define PREF_LONGDATE 3
-#define PREF_FDOW 4 /*First Day Of the Week */
+#define PREF_FDOW 4                     /*First Day Of the Week */
 #define PREF_SHOW_DELETED 5
 #define PREF_SHOW_MODIFIED 6
 #define PREF_TODO_HIDE_COMPLETED 7
@@ -127,9 +127,11 @@
 #define PREF_TODO_NOTE_PANE 95
 #define PREF_EXPENSE_SORT_COLUMN 96
 #define PREF_EXPENSE_SORT_ORDER 97
+#define PREF_KEYR_EXPORT_FILENAME 98
+#define PREF_EXTERNAL_EDITOR 99
 
 /* Number of preferences in use */
-#define NUM_PREFS 98
+#define NUM_PREFS 100
 /* Maximum number of preferences */
 #define MAX_NUM_PREFS 250
 
@@ -160,16 +162,16 @@
 #define CHAR_SET_949_UTF  17 /* Korean (CP949) */
 #define NUM_CHAR_SETS     18
 
-void pref_init();
-int pref_read_rc_file();
-int pref_write_rc_file();
+void pref_init(void);
+int pref_read_rc_file(void);
+int pref_write_rc_file(void);
 int get_pref(int which, long *n, const char **ret);
 int set_pref(int which, long n, const char *string, int save);
 
 /* Specialized functions */
 int set_pref_possibility(int which, long n, int save);
 int get_pref_possibility(int which, int n, char *ret);
-int get_pref_dmy_order();
+int get_pref_dmy_order(void);
 void get_pref_hour_ampm(char *datef);
 int get_pref_time_no_secs(char *datef);
 int get_pref_time_no_secs_no_ampm(char *datef);
