@@ -1,4 +1,4 @@
-/* $Id: utils.h,v 1.87 2011-02-09 22:09:29 rousseau Exp $ */
+/* $Id: utils.h,v 1.89 2011-04-06 12:43:45 rousseau Exp $ */
 
 /*******************************************************************************
  * utils.h
@@ -349,7 +349,7 @@ void entry_set_multiline_truncate(GtkEntry *entry, gboolean value);
 
 void clist_clear(GtkCList *clist);
 
-inline void set_tooltip(int show_tooltip, 
+void set_tooltip(int show_tooltip, 
                         GtkTooltips *tooltips,
                         GtkWidget *widget,
                         const gchar *tip_text,
@@ -394,7 +394,7 @@ void lstrncpy_remove_cr_lfs(char *dest, char *src, int len);
 /* Output LDIF format (RFC 2849) to file.
  * Name is name of item (e.g. "cn")
  * fmt ... is like printf. */
-void ldif_out(FILE *f, char *name, char *fmt, ...);
+void ldif_out(FILE *f, const char *name, const char *fmt, ...);
 
 void cleanup_path(char *path);
 
@@ -473,7 +473,7 @@ int make_category_menu(GtkWidget **category_menu,
                        int add_edit_cat_item);
 
 int jp_copy_file(char *src, char *dest);
-FILE *jp_open_home_file(char *filename, char *mode);
+FILE *jp_open_home_file(const char *filename, const char *mode);
 int jp_close_home_file(FILE *pc_in);
 
 /* Routines used for i18n string manipulation */
